# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class ListVMMachineTypesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count_vm_available': 'int',
        'cpu_models': 'list[CpuModelCategory]',
        'data_centers': 'list[DataCenterCategory]',
        'gpu_models': 'list[GpuModelCategory]',
        'host_configs': 'list[HostConfigCategory]',
        'max_gpu': 'int',
        'max_memory_gib': 'int',
        'max_vcpu': 'int',
        'request': 'ListVMMachineTypesRequest'
    }

    attribute_map = {
        'count_vm_available': 'countVmAvailable',
        'cpu_models': 'cpuModels',
        'data_centers': 'dataCenters',
        'gpu_models': 'gpuModels',
        'host_configs': 'hostConfigs',
        'max_gpu': 'maxGpu',
        'max_memory_gib': 'maxMemoryGib',
        'max_vcpu': 'maxVcpu',
        'request': 'request'
    }

    def __init__(self, count_vm_available=None, cpu_models=None, data_centers=None, gpu_models=None, host_configs=None, max_gpu=None, max_memory_gib=None, max_vcpu=None, request=None, _configuration=None):  # noqa: E501
        """ListVMMachineTypesResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._count_vm_available = None
        self._cpu_models = None
        self._data_centers = None
        self._gpu_models = None
        self._host_configs = None
        self._max_gpu = None
        self._max_memory_gib = None
        self._max_vcpu = None
        self._request = None
        self.discriminator = None

        self.count_vm_available = count_vm_available
        self.cpu_models = cpu_models
        self.data_centers = data_centers
        self.gpu_models = gpu_models
        self.host_configs = host_configs
        self.max_gpu = max_gpu
        self.max_memory_gib = max_memory_gib
        self.max_vcpu = max_vcpu
        self.request = request

    @property
    def count_vm_available(self):
        """Gets the count_vm_available of this ListVMMachineTypesResponse.  # noqa: E501


        :return: The count_vm_available of this ListVMMachineTypesResponse.  # noqa: E501
        :rtype: int
        """
        return self._count_vm_available

    @count_vm_available.setter
    def count_vm_available(self, count_vm_available):
        """Sets the count_vm_available of this ListVMMachineTypesResponse.


        :param count_vm_available: The count_vm_available of this ListVMMachineTypesResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and count_vm_available is None:
            raise ValueError("Invalid value for `count_vm_available`, must not be `None`")  # noqa: E501

        self._count_vm_available = count_vm_available

    @property
    def cpu_models(self):
        """Gets the cpu_models of this ListVMMachineTypesResponse.  # noqa: E501


        :return: The cpu_models of this ListVMMachineTypesResponse.  # noqa: E501
        :rtype: list[CpuModelCategory]
        """
        return self._cpu_models

    @cpu_models.setter
    def cpu_models(self, cpu_models):
        """Sets the cpu_models of this ListVMMachineTypesResponse.


        :param cpu_models: The cpu_models of this ListVMMachineTypesResponse.  # noqa: E501
        :type: list[CpuModelCategory]
        """
        if self._configuration.client_side_validation and cpu_models is None:
            raise ValueError("Invalid value for `cpu_models`, must not be `None`")  # noqa: E501

        self._cpu_models = cpu_models

    @property
    def data_centers(self):
        """Gets the data_centers of this ListVMMachineTypesResponse.  # noqa: E501


        :return: The data_centers of this ListVMMachineTypesResponse.  # noqa: E501
        :rtype: list[DataCenterCategory]
        """
        return self._data_centers

    @data_centers.setter
    def data_centers(self, data_centers):
        """Sets the data_centers of this ListVMMachineTypesResponse.


        :param data_centers: The data_centers of this ListVMMachineTypesResponse.  # noqa: E501
        :type: list[DataCenterCategory]
        """
        if self._configuration.client_side_validation and data_centers is None:
            raise ValueError("Invalid value for `data_centers`, must not be `None`")  # noqa: E501

        self._data_centers = data_centers

    @property
    def gpu_models(self):
        """Gets the gpu_models of this ListVMMachineTypesResponse.  # noqa: E501


        :return: The gpu_models of this ListVMMachineTypesResponse.  # noqa: E501
        :rtype: list[GpuModelCategory]
        """
        return self._gpu_models

    @gpu_models.setter
    def gpu_models(self, gpu_models):
        """Sets the gpu_models of this ListVMMachineTypesResponse.


        :param gpu_models: The gpu_models of this ListVMMachineTypesResponse.  # noqa: E501
        :type: list[GpuModelCategory]
        """
        if self._configuration.client_side_validation and gpu_models is None:
            raise ValueError("Invalid value for `gpu_models`, must not be `None`")  # noqa: E501

        self._gpu_models = gpu_models

    @property
    def host_configs(self):
        """Gets the host_configs of this ListVMMachineTypesResponse.  # noqa: E501


        :return: The host_configs of this ListVMMachineTypesResponse.  # noqa: E501
        :rtype: list[HostConfigCategory]
        """
        return self._host_configs

    @host_configs.setter
    def host_configs(self, host_configs):
        """Sets the host_configs of this ListVMMachineTypesResponse.


        :param host_configs: The host_configs of this ListVMMachineTypesResponse.  # noqa: E501
        :type: list[HostConfigCategory]
        """
        if self._configuration.client_side_validation and host_configs is None:
            raise ValueError("Invalid value for `host_configs`, must not be `None`")  # noqa: E501

        self._host_configs = host_configs

    @property
    def max_gpu(self):
        """Gets the max_gpu of this ListVMMachineTypesResponse.  # noqa: E501


        :return: The max_gpu of this ListVMMachineTypesResponse.  # noqa: E501
        :rtype: int
        """
        return self._max_gpu

    @max_gpu.setter
    def max_gpu(self, max_gpu):
        """Sets the max_gpu of this ListVMMachineTypesResponse.


        :param max_gpu: The max_gpu of this ListVMMachineTypesResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and max_gpu is None:
            raise ValueError("Invalid value for `max_gpu`, must not be `None`")  # noqa: E501

        self._max_gpu = max_gpu

    @property
    def max_memory_gib(self):
        """Gets the max_memory_gib of this ListVMMachineTypesResponse.  # noqa: E501


        :return: The max_memory_gib of this ListVMMachineTypesResponse.  # noqa: E501
        :rtype: int
        """
        return self._max_memory_gib

    @max_memory_gib.setter
    def max_memory_gib(self, max_memory_gib):
        """Sets the max_memory_gib of this ListVMMachineTypesResponse.


        :param max_memory_gib: The max_memory_gib of this ListVMMachineTypesResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and max_memory_gib is None:
            raise ValueError("Invalid value for `max_memory_gib`, must not be `None`")  # noqa: E501

        self._max_memory_gib = max_memory_gib

    @property
    def max_vcpu(self):
        """Gets the max_vcpu of this ListVMMachineTypesResponse.  # noqa: E501


        :return: The max_vcpu of this ListVMMachineTypesResponse.  # noqa: E501
        :rtype: int
        """
        return self._max_vcpu

    @max_vcpu.setter
    def max_vcpu(self, max_vcpu):
        """Sets the max_vcpu of this ListVMMachineTypesResponse.


        :param max_vcpu: The max_vcpu of this ListVMMachineTypesResponse.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and max_vcpu is None:
            raise ValueError("Invalid value for `max_vcpu`, must not be `None`")  # noqa: E501

        self._max_vcpu = max_vcpu

    @property
    def request(self):
        """Gets the request of this ListVMMachineTypesResponse.  # noqa: E501


        :return: The request of this ListVMMachineTypesResponse.  # noqa: E501
        :rtype: ListVMMachineTypesRequest
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this ListVMMachineTypesResponse.


        :param request: The request of this ListVMMachineTypesResponse.  # noqa: E501
        :type: ListVMMachineTypesRequest
        """
        if self._configuration.client_side_validation and request is None:
            raise ValueError("Invalid value for `request`, must not be `None`")  # noqa: E501

        self._request = request

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ListVMMachineTypesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListVMMachineTypesResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListVMMachineTypesResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from src.cudo_compute.configuration import Configuration


class MachineType(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count_clusters': 'int',
        'count_hosts': 'int',
        'count_hosts_active': 'int',
        'count_hosts_inactive': 'int',
        'machine_type': 'str'
    }

    attribute_map = {
        'count_clusters': 'countClusters',
        'count_hosts': 'countHosts',
        'count_hosts_active': 'countHostsActive',
        'count_hosts_inactive': 'countHostsInactive',
        'machine_type': 'machineType'
    }

    def __init__(self, count_clusters=None, count_hosts=None, count_hosts_active=None, count_hosts_inactive=None, machine_type=None, _configuration=None):  # noqa: E501
        """MachineType - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._count_clusters = None
        self._count_hosts = None
        self._count_hosts_active = None
        self._count_hosts_inactive = None
        self._machine_type = None
        self.discriminator = None

        self.count_clusters = count_clusters
        self.count_hosts = count_hosts
        self.count_hosts_active = count_hosts_active
        self.count_hosts_inactive = count_hosts_inactive
        self.machine_type = machine_type

    @property
    def count_clusters(self):
        """Gets the count_clusters of this MachineType.  # noqa: E501


        :return: The count_clusters of this MachineType.  # noqa: E501
        :rtype: int
        """
        return self._count_clusters

    @count_clusters.setter
    def count_clusters(self, count_clusters):
        """Sets the count_clusters of this MachineType.


        :param count_clusters: The count_clusters of this MachineType.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and count_clusters is None:
            raise ValueError("Invalid value for `count_clusters`, must not be `None`")  # noqa: E501

        self._count_clusters = count_clusters

    @property
    def count_hosts(self):
        """Gets the count_hosts of this MachineType.  # noqa: E501


        :return: The count_hosts of this MachineType.  # noqa: E501
        :rtype: int
        """
        return self._count_hosts

    @count_hosts.setter
    def count_hosts(self, count_hosts):
        """Sets the count_hosts of this MachineType.


        :param count_hosts: The count_hosts of this MachineType.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and count_hosts is None:
            raise ValueError("Invalid value for `count_hosts`, must not be `None`")  # noqa: E501

        self._count_hosts = count_hosts

    @property
    def count_hosts_active(self):
        """Gets the count_hosts_active of this MachineType.  # noqa: E501


        :return: The count_hosts_active of this MachineType.  # noqa: E501
        :rtype: int
        """
        return self._count_hosts_active

    @count_hosts_active.setter
    def count_hosts_active(self, count_hosts_active):
        """Sets the count_hosts_active of this MachineType.


        :param count_hosts_active: The count_hosts_active of this MachineType.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and count_hosts_active is None:
            raise ValueError("Invalid value for `count_hosts_active`, must not be `None`")  # noqa: E501

        self._count_hosts_active = count_hosts_active

    @property
    def count_hosts_inactive(self):
        """Gets the count_hosts_inactive of this MachineType.  # noqa: E501


        :return: The count_hosts_inactive of this MachineType.  # noqa: E501
        :rtype: int
        """
        return self._count_hosts_inactive

    @count_hosts_inactive.setter
    def count_hosts_inactive(self, count_hosts_inactive):
        """Sets the count_hosts_inactive of this MachineType.


        :param count_hosts_inactive: The count_hosts_inactive of this MachineType.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and count_hosts_inactive is None:
            raise ValueError("Invalid value for `count_hosts_inactive`, must not be `None`")  # noqa: E501

        self._count_hosts_inactive = count_hosts_inactive

    @property
    def machine_type(self):
        """Gets the machine_type of this MachineType.  # noqa: E501


        :return: The machine_type of this MachineType.  # noqa: E501
        :rtype: str
        """
        return self._machine_type

    @machine_type.setter
    def machine_type(self, machine_type):
        """Sets the machine_type of this MachineType.


        :param machine_type: The machine_type of this MachineType.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and machine_type is None:
            raise ValueError("Invalid value for `machine_type`, must not be `None`")  # noqa: E501

        self._machine_type = machine_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MachineType, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MachineType):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MachineType):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from src.cudo_compute.configuration import Configuration


class CreateBillingAccountRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'display_name': 'str',
        'email': 'str',
        'invoice_name': 'str',
        'referral': 'str',
        'tax_ids': 'list[TaxId]'
    }

    attribute_map = {
        'display_name': 'displayName',
        'email': 'email',
        'invoice_name': 'invoiceName',
        'referral': 'referral',
        'tax_ids': 'taxIds'
    }

    def __init__(self, display_name=None, email=None, invoice_name=None, referral=None, tax_ids=None, _configuration=None):  # noqa: E501
        """CreateBillingAccountRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._display_name = None
        self._email = None
        self._invoice_name = None
        self._referral = None
        self._tax_ids = None
        self.discriminator = None

        self.display_name = display_name
        self.email = email
        self.invoice_name = invoice_name
        if referral is not None:
            self.referral = referral
        if tax_ids is not None:
            self.tax_ids = tax_ids

    @property
    def display_name(self):
        """Gets the display_name of this CreateBillingAccountRequest.  # noqa: E501


        :return: The display_name of this CreateBillingAccountRequest.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this CreateBillingAccountRequest.


        :param display_name: The display_name of this CreateBillingAccountRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and display_name is None:
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501

        self._display_name = display_name

    @property
    def email(self):
        """Gets the email of this CreateBillingAccountRequest.  # noqa: E501


        :return: The email of this CreateBillingAccountRequest.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this CreateBillingAccountRequest.


        :param email: The email of this CreateBillingAccountRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def invoice_name(self):
        """Gets the invoice_name of this CreateBillingAccountRequest.  # noqa: E501


        :return: The invoice_name of this CreateBillingAccountRequest.  # noqa: E501
        :rtype: str
        """
        return self._invoice_name

    @invoice_name.setter
    def invoice_name(self, invoice_name):
        """Sets the invoice_name of this CreateBillingAccountRequest.


        :param invoice_name: The invoice_name of this CreateBillingAccountRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and invoice_name is None:
            raise ValueError("Invalid value for `invoice_name`, must not be `None`")  # noqa: E501

        self._invoice_name = invoice_name

    @property
    def referral(self):
        """Gets the referral of this CreateBillingAccountRequest.  # noqa: E501


        :return: The referral of this CreateBillingAccountRequest.  # noqa: E501
        :rtype: str
        """
        return self._referral

    @referral.setter
    def referral(self, referral):
        """Sets the referral of this CreateBillingAccountRequest.


        :param referral: The referral of this CreateBillingAccountRequest.  # noqa: E501
        :type: str
        """

        self._referral = referral

    @property
    def tax_ids(self):
        """Gets the tax_ids of this CreateBillingAccountRequest.  # noqa: E501


        :return: The tax_ids of this CreateBillingAccountRequest.  # noqa: E501
        :rtype: list[TaxId]
        """
        return self._tax_ids

    @tax_ids.setter
    def tax_ids(self, tax_ids):
        """Sets the tax_ids of this CreateBillingAccountRequest.


        :param tax_ids: The tax_ids of this CreateBillingAccountRequest.  # noqa: E501
        :type: list[TaxId]
        """

        self._tax_ids = tax_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateBillingAccountRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateBillingAccountRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateBillingAccountRequest):
            return True

        return self.to_dict() != other.to_dict()



from ruamel.yaml import YAML
import os

home = os.path.expanduser("~")


def load_config(path, context_name):
    key_config = None
    context_config = None
    error = None

    with open(path, 'r') as file:
        yaml = YAML(typ='safe')
        config_data = yaml.load(file)

    if config_data['configVersion'] != "v0":
        error = Exception("Only config version v0 is supported")
        return key_config, context_config, error

    if not context_name:
        if 'current-context' in config_data:
            context_name = config_data['current-context']
        else:
            return key_config, context_config, Exception("No current context selected")

    if 'contexts' in config_data:
        for context_data in config_data['contexts']:
            if context_data['name'] == context_name:
                context_config = context_data
                break

    if not context_config:
        error = Exception("Context not found")
        return key_config, context_config, error

    if 'keys' in config_data:
        for key_data in config_data['keys']:
            if key_data['name'] == context_config['key']:
                key_config = key_data

    if not key_config:
        error = Exception("Key not found")

    return key_config, context_config, error






# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.data_centers_api import DataCentersApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestDataCentersApi(unittest.TestCase):
    """DataCentersApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.data_centers_api.DataCentersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_count_hosts(self):
        """Test case for count_hosts

        Get host count  # noqa: E501
        """
        pass

    def test_create_data_center(self):
        """Test case for create_data_center

        Create data center  # noqa: E501
        """
        pass

    def test_delete_data_center(self):
        """Test case for delete_data_center

        Delete data center  # noqa: E501
        """
        pass

    def test_get_data_center(self):
        """Test case for get_data_center

        Get data center  # noqa: E501
        """
        pass

    def test_get_data_center_live_utilization(self):
        """Test case for get_data_center_live_utilization

        Get live utilization  # noqa: E501
        """
        pass

    def test_get_data_center_revenue_by_resource(self):
        """Test case for get_data_center_revenue_by_resource

        Get revenue by resource  # noqa: E501
        """
        pass

    def test_get_data_center_revenue_time_series(self):
        """Test case for get_data_center_revenue_time_series

        Get revenue time series  # noqa: E501
        """
        pass

    def test_list_clusters(self):
        """Test case for list_clusters

        List clusters  # noqa: E501
        """
        pass

    def test_list_data_centers(self):
        """Test case for list_data_centers

        List data centers  # noqa: E501
        """
        pass

    def test_list_hosts(self):
        """Test case for list_hosts

        List hosts  # noqa: E501
        """
        pass

    def test_update_data_center(self):
        """Test case for update_data_center

        Update data center  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cudo_compute.api_client import ApiClient


class NetworksApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_network(self, project_id, create_network_body, **kwargs):  # noqa: E501
        """Create network  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_network(project_id, create_network_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param CreateNetworkBody create_network_body: (required)
        :return: CreateNetworkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_network_with_http_info(project_id, create_network_body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_network_with_http_info(project_id, create_network_body, **kwargs)  # noqa: E501
            return data

    def create_network_with_http_info(self, project_id, create_network_body, **kwargs):  # noqa: E501
        """Create network  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_network_with_http_info(project_id, create_network_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param CreateNetworkBody create_network_body: (required)
        :return: CreateNetworkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'create_network_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_network" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `create_network`")  # noqa: E501
        # verify the required parameter 'create_network_body' is set
        if self.api_client.client_side_validation and ('create_network_body' not in params or
                                                       params['create_network_body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_network_body` when calling `create_network`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_network_body' in params:
            body_params = params['create_network_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/networks', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateNetworkResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_security_group(self, security_group_project_id, security_group, **kwargs):  # noqa: E501
        """Create security group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_security_group(security_group_project_id, security_group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str security_group_project_id: (required)
        :param SecurityGroup security_group: (required)
        :return: CreateSecurityGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_security_group_with_http_info(security_group_project_id, security_group, **kwargs)  # noqa: E501
        else:
            (data) = self.create_security_group_with_http_info(security_group_project_id, security_group, **kwargs)  # noqa: E501
            return data

    def create_security_group_with_http_info(self, security_group_project_id, security_group, **kwargs):  # noqa: E501
        """Create security group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_security_group_with_http_info(security_group_project_id, security_group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str security_group_project_id: (required)
        :param SecurityGroup security_group: (required)
        :return: CreateSecurityGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['security_group_project_id', 'security_group']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_security_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'security_group_project_id' is set
        if self.api_client.client_side_validation and ('security_group_project_id' not in params or
                                                       params['security_group_project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `security_group_project_id` when calling `create_security_group`")  # noqa: E501
        # verify the required parameter 'security_group' is set
        if self.api_client.client_side_validation and ('security_group' not in params or
                                                       params['security_group'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `security_group` when calling `create_security_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'security_group_project_id' in params:
            path_params['securityGroup.projectId'] = params['security_group_project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'security_group' in params:
            body_params = params['security_group']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{securityGroup.projectId}/networks/security-groups', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateSecurityGroupResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_network(self, project_id, id, network_id, **kwargs):  # noqa: E501
        """Delete network  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_network(project_id, id, network_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str network_id: (required)
        :return: DeleteNetworkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_network_with_http_info(project_id, id, network_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_network_with_http_info(project_id, id, network_id, **kwargs)  # noqa: E501
            return data

    def delete_network_with_http_info(self, project_id, id, network_id, **kwargs):  # noqa: E501
        """Delete network  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_network_with_http_info(project_id, id, network_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str network_id: (required)
        :return: DeleteNetworkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'network_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_network" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `delete_network`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_network`")  # noqa: E501
        # verify the required parameter 'network_id' is set
        if self.api_client.client_side_validation and ('network_id' not in params or
                                                       params['network_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `network_id` when calling `delete_network`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'network_id' in params:
            query_params.append(('networkId', params['network_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/networks/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteNetworkResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_security_group(self, project_id, id, **kwargs):  # noqa: E501
        """Delete security group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_security_group(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: DeleteSecurityGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_security_group_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_security_group_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def delete_security_group_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Delete security group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_security_group_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: DeleteSecurityGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_security_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `delete_security_group`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_security_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/networks/security-groups/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteSecurityGroupResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_network(self, project_id, id, **kwargs):  # noqa: E501
        """Get network  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_network(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: GetNetworkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_network_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_network_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def get_network_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Get network  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_network_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: GetNetworkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_network" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `get_network`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_network`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/networks/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetNetworkResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_security_group(self, project_id, id, **kwargs):  # noqa: E501
        """Get a security group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_security_group(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: GetSecurityGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_security_group_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_security_group_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def get_security_group_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Get a security group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_security_group_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: GetSecurityGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_security_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `get_security_group`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_security_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/networks/security-groups/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetSecurityGroupResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_networks(self, project_id, **kwargs):  # noqa: E501
        """List networks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_networks(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param int page_number:
        :param int page_size:
        :return: ListNetworksResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_networks_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_networks_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def list_networks_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """List networks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_networks_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param int page_number:
        :param int page_size:
        :return: ListNetworksResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'page_number', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_networks" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `list_networks`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/networks', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListNetworksResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_security_groups(self, project_id, **kwargs):  # noqa: E501
        """List security groups  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_security_groups(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str data_center_id:
        :param int page_number:
        :param int page_size:
        :return: ListSecurityGroupsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_security_groups_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_security_groups_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def list_security_groups_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """List security groups  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_security_groups_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str data_center_id:
        :param int page_number:
        :param int page_size:
        :return: ListSecurityGroupsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'data_center_id', 'page_number', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_security_groups" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `list_security_groups`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'data_center_id' in params:
            query_params.append(('dataCenterId', params['data_center_id']))  # noqa: E501
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/networks/security-groups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListSecurityGroupsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_network(self, project_id, id, network_id, **kwargs):  # noqa: E501
        """Start network  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_network(project_id, id, network_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str network_id: (required)
        :return: StartNetworkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.start_network_with_http_info(project_id, id, network_id, **kwargs)  # noqa: E501
        else:
            (data) = self.start_network_with_http_info(project_id, id, network_id, **kwargs)  # noqa: E501
            return data

    def start_network_with_http_info(self, project_id, id, network_id, **kwargs):  # noqa: E501
        """Start network  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_network_with_http_info(project_id, id, network_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str network_id: (required)
        :return: StartNetworkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'network_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_network" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `start_network`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `start_network`")  # noqa: E501
        # verify the required parameter 'network_id' is set
        if self.api_client.client_side_validation and ('network_id' not in params or
                                                       params['network_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `network_id` when calling `start_network`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'network_id' in params:
            query_params.append(('networkId', params['network_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/networks/{id}/start', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StartNetworkResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def stop_network(self, project_id, id, network_id, **kwargs):  # noqa: E501
        """Stop network  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stop_network(project_id, id, network_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str network_id: (required)
        :return: StopNetworkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.stop_network_with_http_info(project_id, id, network_id, **kwargs)  # noqa: E501
        else:
            (data) = self.stop_network_with_http_info(project_id, id, network_id, **kwargs)  # noqa: E501
            return data

    def stop_network_with_http_info(self, project_id, id, network_id, **kwargs):  # noqa: E501
        """Stop network  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stop_network_with_http_info(project_id, id, network_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str network_id: (required)
        :return: StopNetworkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'network_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method stop_network" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `stop_network`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `stop_network`")  # noqa: E501
        # verify the required parameter 'network_id' is set
        if self.api_client.client_side_validation and ('network_id' not in params or
                                                       params['network_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `network_id` when calling `stop_network`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'network_id' in params:
            query_params.append(('networkId', params['network_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/networks/{id}/stop', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StopNetworkResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_security_group(self, security_group_project_id, security_group_id, security_group, **kwargs):  # noqa: E501
        """Update security group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_security_group(security_group_project_id, security_group_id, security_group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str security_group_project_id: (required)
        :param str security_group_id: (required)
        :param SecurityGroup1 security_group: (required)
        :return: UpdateSecurityGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_security_group_with_http_info(security_group_project_id, security_group_id, security_group, **kwargs)  # noqa: E501
        else:
            (data) = self.update_security_group_with_http_info(security_group_project_id, security_group_id, security_group, **kwargs)  # noqa: E501
            return data

    def update_security_group_with_http_info(self, security_group_project_id, security_group_id, security_group, **kwargs):  # noqa: E501
        """Update security group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_security_group_with_http_info(security_group_project_id, security_group_id, security_group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str security_group_project_id: (required)
        :param str security_group_id: (required)
        :param SecurityGroup1 security_group: (required)
        :return: UpdateSecurityGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['security_group_project_id', 'security_group_id', 'security_group']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_security_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'security_group_project_id' is set
        if self.api_client.client_side_validation and ('security_group_project_id' not in params or
                                                       params['security_group_project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `security_group_project_id` when calling `update_security_group`")  # noqa: E501
        # verify the required parameter 'security_group_id' is set
        if self.api_client.client_side_validation and ('security_group_id' not in params or
                                                       params['security_group_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `security_group_id` when calling `update_security_group`")  # noqa: E501
        # verify the required parameter 'security_group' is set
        if self.api_client.client_side_validation and ('security_group' not in params or
                                                       params['security_group'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `security_group` when calling `update_security_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'security_group_project_id' in params:
            path_params['securityGroup.projectId'] = params['security_group_project_id']  # noqa: E501
        if 'security_group_id' in params:
            path_params['securityGroup.id'] = params['security_group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'security_group' in params:
            body_params = params['security_group']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{securityGroup.projectId}/networks/security-groups/{securityGroup.id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateSecurityGroupResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from cudo_compute.api.api_keys_api import APIKeysApi
from cudo_compute.api.billing_api import BillingApi
from cudo_compute.api.data_centers_api import DataCentersApi
from cudo_compute.api.disks_api import DisksApi
from cudo_compute.api.machine_types_api import MachineTypesApi
from cudo_compute.api.networks_api import NetworksApi
from cudo_compute.api.object_storage_api import ObjectStorageApi
from cudo_compute.api.permissions_api import PermissionsApi
from cudo_compute.api.projects_api import ProjectsApi
from cudo_compute.api.ssh_keys_api import SSHKeysApi
from cudo_compute.api.search_api import SearchApi
from cudo_compute.api.user_api import UserApi
from cudo_compute.api.virtual_machines_api import VirtualMachinesApi

# import ApiClient
from cudo_compute.api_client import ApiClient
from cudo_compute.configuration import Configuration
# import models into sdk package
from cudo_compute.models.activate_body import ActivateBody
from cudo_compute.models.add_billing_account_user_permission_body import AddBillingAccountUserPermissionBody
from cudo_compute.models.add_data_center_user_permission_body import AddDataCenterUserPermissionBody
from cudo_compute.models.add_project_user_permission_body import AddProjectUserPermissionBody
from cudo_compute.models.any import Any
from cudo_compute.models.api_key import ApiKey
from cudo_compute.models.attach_security_group_response import AttachSecurityGroupResponse
from cudo_compute.models.attach_storage_disk_response import AttachStorageDiskResponse
from cudo_compute.models.billing_account import BillingAccount
from cudo_compute.models.billing_account_payment_method import BillingAccountPaymentMethod
from cudo_compute.models.billing_account_payment_methods import BillingAccountPaymentMethods
from cudo_compute.models.billing_account_setup_intent import BillingAccountSetupIntent
from cudo_compute.models.billing_account_spend_row import BillingAccountSpendRow
from cudo_compute.models.cluster import Cluster
from cudo_compute.models.connect_vm_response import ConnectVMResponse
from cudo_compute.models.count_hosts_response import CountHostsResponse
from cudo_compute.models.count_vms_response import CountVMsResponse
from cudo_compute.models.cpu_model_category import CpuModelCategory
from cudo_compute.models.create_billing_account_request import CreateBillingAccountRequest
from cudo_compute.models.create_disk_snapshot_body import CreateDiskSnapshotBody
from cudo_compute.models.create_disk_snapshot_response import CreateDiskSnapshotResponse
from cudo_compute.models.create_network_body import CreateNetworkBody
from cudo_compute.models.create_network_response import CreateNetworkResponse
from cudo_compute.models.create_object_storage_user_body import CreateObjectStorageUserBody
from cudo_compute.models.create_private_vm_image_response import CreatePrivateVMImageResponse
from cudo_compute.models.create_security_group_response import CreateSecurityGroupResponse
from cudo_compute.models.create_storage_disk_body import CreateStorageDiskBody
from cudo_compute.models.create_storage_disk_response import CreateStorageDiskResponse
from cudo_compute.models.create_vm_body import CreateVMBody
from cudo_compute.models.create_vm_request_nic import CreateVMRequestNIC
from cudo_compute.models.create_vm_response import CreateVMResponse
from cudo_compute.models.data_center import DataCenter
from cudo_compute.models.data_center_category import DataCenterCategory
from cudo_compute.models.data_center_revenue_resource import DataCenterRevenueResource
from cudo_compute.models.data_center_time_revenue import DataCenterTimeRevenue
from cudo_compute.models.decimal import Decimal
from cudo_compute.models.delete_disk_snapshot_response import DeleteDiskSnapshotResponse
from cudo_compute.models.delete_network_response import DeleteNetworkResponse
from cudo_compute.models.delete_object_storage_key_response import DeleteObjectStorageKeyResponse
from cudo_compute.models.delete_object_storage_user_response import DeleteObjectStorageUserResponse
from cudo_compute.models.delete_private_vm_image_response import DeletePrivateVMImageResponse
from cudo_compute.models.delete_security_group_response import DeleteSecurityGroupResponse
from cudo_compute.models.delete_storage_disk_response import DeleteStorageDiskResponse
from cudo_compute.models.detach_security_group_response import DetachSecurityGroupResponse
from cudo_compute.models.detach_storage_disk_response import DetachStorageDiskResponse
from cudo_compute.models.disk import Disk
from cudo_compute.models.disk_state import DiskState
from cudo_compute.models.disk_storage_class import DiskStorageClass
from cudo_compute.models.disk_storage_price_hr import DiskStoragePriceHr
from cudo_compute.models.disk_type import DiskType
from cudo_compute.models.generate_api_key_request import GenerateApiKeyRequest
from cudo_compute.models.get_billing_account_details_response import GetBillingAccountDetailsResponse
from cudo_compute.models.get_billing_account_spend_details_response import GetBillingAccountSpendDetailsResponse
from cudo_compute.models.get_billing_account_stripe_invoices_response import GetBillingAccountStripeInvoicesResponse
from cudo_compute.models.get_data_center_live_utilization_response import GetDataCenterLiveUtilizationResponse
from cudo_compute.models.get_data_center_revenue_by_resource_response import GetDataCenterRevenueByResourceResponse
from cudo_compute.models.get_data_center_revenue_time_series_response import GetDataCenterRevenueTimeSeriesResponse
from cudo_compute.models.get_disk_response import GetDiskResponse
from cudo_compute.models.get_machine_type_live_utilization_response import GetMachineTypeLiveUtilizationResponse
from cudo_compute.models.get_machine_type_response import GetMachineTypeResponse
from cudo_compute.models.get_network_response import GetNetworkResponse
from cudo_compute.models.get_object_storage_session_key_response import GetObjectStorageSessionKeyResponse
from cudo_compute.models.get_private_vm_image_response import GetPrivateVMImageResponse
from cudo_compute.models.get_security_group_response import GetSecurityGroupResponse
from cudo_compute.models.get_vm_response import GetVMResponse
from cudo_compute.models.gpu_model_category import GpuModelCategory
from cudo_compute.models.host import Host
from cudo_compute.models.host_config_category import HostConfigCategory
from cudo_compute.models.identity_verification_session import IdentityVerificationSession
from cudo_compute.models.image import Image
from cudo_compute.models.interval import Interval
from cudo_compute.models.invoice import Invoice
from cudo_compute.models.list_api_keys_response import ListApiKeysResponse
from cudo_compute.models.list_billing_accounts_response import ListBillingAccountsResponse
from cudo_compute.models.list_clusters_response import ListClustersResponse
from cudo_compute.models.list_data_centers_response import ListDataCentersResponse
from cudo_compute.models.list_disk_snapshots_response import ListDiskSnapshotsResponse
from cudo_compute.models.list_disks_response import ListDisksResponse
from cudo_compute.models.list_hosts_response import ListHostsResponse
from cudo_compute.models.list_machine_types_response import ListMachineTypesResponse
from cudo_compute.models.list_networks_response import ListNetworksResponse
from cudo_compute.models.list_object_storage_buckets_response import ListObjectStorageBucketsResponse
from cudo_compute.models.list_object_storage_keys_response import ListObjectStorageKeysResponse
from cudo_compute.models.list_object_storage_users_response import ListObjectStorageUsersResponse
from cudo_compute.models.list_outstanding_stripe_invoices_response import ListOutstandingStripeInvoicesResponse
from cudo_compute.models.list_private_vm_images_response import ListPrivateVMImagesResponse
from cudo_compute.models.list_private_vm_images_response_private_image import ListPrivateVMImagesResponsePrivateImage
from cudo_compute.models.list_project_ssh_keys_response import ListProjectSshKeysResponse
from cudo_compute.models.list_projects_response import ListProjectsResponse
from cudo_compute.models.list_public_vm_images_response import ListPublicVMImagesResponse
from cudo_compute.models.list_regions_response import ListRegionsResponse
from cudo_compute.models.list_security_groups_response import ListSecurityGroupsResponse
from cudo_compute.models.list_ssh_keys_response import ListSshKeysResponse
from cudo_compute.models.list_user_permissions_response import ListUserPermissionsResponse
from cudo_compute.models.list_vm_data_centers_response import ListVMDataCentersResponse
from cudo_compute.models.list_vm_disks_response import ListVMDisksResponse
from cudo_compute.models.list_vm_machine_types_request import ListVMMachineTypesRequest
from cudo_compute.models.list_vm_machine_types_response import ListVMMachineTypesResponse
from cudo_compute.models.list_vms_response import ListVMsResponse
from cudo_compute.models.machine_type import MachineType
from cudo_compute.models.monitor_vm_response import MonitorVMResponse
from cudo_compute.models.network import Network
from cudo_compute.models.network_price_hr import NetworkPriceHr
from cudo_compute.models.network_state import NetworkState
from cudo_compute.models.object_storage_bucket import ObjectStorageBucket
from cudo_compute.models.object_storage_key import ObjectStorageKey
from cudo_compute.models.object_storage_user import ObjectStorageUser
from cudo_compute.models.payment_method_card import PaymentMethodCard
from cudo_compute.models.payment_method_paypal import PaymentMethodPaypal
from cudo_compute.models.point import Point
from cudo_compute.models.profile import Profile
from cudo_compute.models.project import Project
from cudo_compute.models.protocol import Protocol
from cudo_compute.models.reboot_vm_response import RebootVMResponse
from cudo_compute.models.region import Region
from cudo_compute.models.remove_billing_account_payment_method_response import RemoveBillingAccountPaymentMethodResponse
from cudo_compute.models.remove_billing_account_user_permission_body import RemoveBillingAccountUserPermissionBody
from cudo_compute.models.remove_data_center_user_permission_body import RemoveDataCenterUserPermissionBody
from cudo_compute.models.remove_project_user_permission_body import RemoveProjectUserPermissionBody
from cudo_compute.models.resize_vm_disk_response import ResizeVMDiskResponse
from cudo_compute.models.resize_vm_response import ResizeVMResponse
from cudo_compute.models.revert_disk_response import RevertDiskResponse
from cudo_compute.models.role import Role
from cudo_compute.models.rule import Rule
from cudo_compute.models.rule_type import RuleType
from cudo_compute.models.security_group import SecurityGroup
from cudo_compute.models.security_group1 import SecurityGroup1
from cudo_compute.models.security_group_rule import SecurityGroupRule
from cudo_compute.models.set_billing_account_default_payment_method_response import SetBillingAccountDefaultPaymentMethodResponse
from cudo_compute.models.snapshot import Snapshot
from cudo_compute.models.ssh_key import SshKey
from cudo_compute.models.ssh_key_source import SshKeySource
from cudo_compute.models.start_network_response import StartNetworkResponse
from cudo_compute.models.start_vm_response import StartVMResponse
from cudo_compute.models.status import Status
from cudo_compute.models.stop_network_response import StopNetworkResponse
from cudo_compute.models.stop_vm_response import StopVMResponse
from cudo_compute.models.stripe_customer import StripeCustomer
from cudo_compute.models.tax_id import TaxId
from cudo_compute.models.terminate_vm_response import TerminateVMResponse
from cudo_compute.models.unit import Unit
from cudo_compute.models.update_billing_account_body import UpdateBillingAccountBody
from cudo_compute.models.update_private_vm_image_response import UpdatePrivateVMImageResponse
from cudo_compute.models.update_security_group_response import UpdateSecurityGroupResponse
from cudo_compute.models.update_vm_metadata_body import UpdateVMMetadataBody
from cudo_compute.models.update_vm_metadata_response import UpdateVMMetadataResponse
from cudo_compute.models.user_permission import UserPermission
from cudo_compute.models.v1_private_image import V1PrivateImage
from cudo_compute.models.v1billingaccountsbilling_account_id_billing_account import V1billingaccountsbillingAccountIdBillingAccount
from cudo_compute.models.vm import VM
from cudo_compute.models.vm_data_center import VMDataCenter
from cudo_compute.models.vm_data_center_storage_class import VMDataCenterStorageClass
from cudo_compute.models.vm_monitoring_item import VMMonitoringItem
from cudo_compute.models.vmnic import VMNIC
from cudo_compute.models.v_router_size import VRouterSize
from cudo_compute.models.vm_state import VmState
import cudo_compute.auth_config as AuthConfig
import cudo_compute.cudo_api as cudo_api



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.projects_api import ProjectsApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.projects_api.ProjectsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_project(self):
        """Test case for create_project

        Create  # noqa: E501
        """
        pass

    def test_delete_project(self):
        """Test case for delete_project

        Delete  # noqa: E501
        """
        pass

    def test_get_project(self):
        """Test case for get_project

        Get  # noqa: E501
        """
        pass

    def test_list_project_ssh_keys(self):
        """Test case for list_project_ssh_keys

        List SSH keys  # noqa: E501
        """
        pass

    def test_list_projects(self):
        """Test case for list_projects

        List  # noqa: E501
        """
        pass

    def test_update_project(self):
        """Test case for update_project

        Update  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
